summaryrefslogtreecommitdiffstats
path: root/src/jrummikub/view/ITablePanel.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/jrummikub/view/ITablePanel.java')
-rw-r--r--src/jrummikub/view/ITablePanel.java95
1 files changed, 56 insertions, 39 deletions
diff --git a/src/jrummikub/view/ITablePanel.java b/src/jrummikub/view/ITablePanel.java
index ec7f3ea..f17d1fe 100644
--- a/src/jrummikub/view/ITablePanel.java
+++ b/src/jrummikub/view/ITablePanel.java
@@ -4,48 +4,65 @@ import java.util.Map;
import jrummikub.model.Position;
import jrummikub.model.StoneSet;
+import jrummikub.util.Event1;
/**
* The view of the table, where the stone sets lie
*/
public interface ITablePanel extends IStonePanel, IClickable {
- /**
- * Sets the player name on the left label
- *
- * @param playerName
- * the name to set
- */
- public void setLeftPlayerName(String playerName);
-
- /**
- * Sets the player name on the top label
- *
- * @param playerName
- * the name to set
- */
- public void setTopPlayerName(String playerName);
-
- /**
- * Sets the player name on the right label
- *
- * @param playerName
- * the name to set
- */
- public void setRightPlayerName(String playerName);
-
- /**
- * Sets the stone sets lying on the table
- *
- * @param stoneSets
- * set stone sets on the table
- */
- public void setStoneSets(Map<StoneSet, Position> stoneSets);
-
- /**
- * Returns the stone collection (the panel showing the stones currently
- * selected)
- *
- * @return the stone collection
- */
- IStoneCollectionPanel getStoneCollectionPanel();
+ /**
+ * Sets the player name on the left label
+ *
+ * @param playerName
+ * the name to set
+ */
+ public void setLeftPlayerName(String playerName);
+
+ /**
+ * Sets the player name on the top label
+ *
+ * @param playerName
+ * the name to set
+ */
+ public void setTopPlayerName(String playerName);
+
+ /**
+ * Sets the player name on the right label
+ *
+ * @param playerName
+ * the name to set
+ */
+ public void setRightPlayerName(String playerName);
+
+ /**
+ * Sets the stone sets lying on the table
+ *
+ * @param stoneSets
+ * set stone sets on the table
+ */
+ public void setStoneSets(Map<StoneSet, Position> stoneSets);
+
+ /**
+ * Returns the stone collection (the panel showing the stones currently
+ * selected)
+ *
+ * @return the stone collection
+ */
+ public IStoneCollectionPanel getStoneCollectionPanel();
+
+ /**
+ * the left connector click event is emitted when the player clicks on a left
+ * connector of a stone set on the table .
+ *
+ * @return the event
+ */
+ public Event1<StoneSet> getLeftConnectorClickEvent();
+
+ /**
+ * the right connector click event is emitted when the player clicks on a
+ * right connector of a stone set on the table .
+ *
+ * @return the event
+ */
+ public Event1<StoneSet> getRightConnectorClickEvent();
}